==> gitlab4j-api-4.7.17-sources.jar: org/gitlab4j/api/systemhooks/RepositorySystemHookEvent.java <==
package org.gitlab4j.api.systemhooks;

import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.gitlab4j.api.webhook.EventProject;

@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class RepositorySystemHookEvent implements SystemHookEvent {

    public static final String REPOSITORY_UPDATE_EVENT = "repository_update";

    private String eventName;
    private Integer userId;
    private String userName;
    private String userEmail;
    private String userAvatar;

    private Integer projectId;
    private EventProject project;

    private List<RepositoryChange> changes;
    private List<String> refs;


    public String getEventName() {
        return (eventName);
    }

    public void setEventName(String eventName) {
        this.eventName = eventName;
    }

    public Integer getUserId() {
        return this.userId;
    }

    public void setUserId(Integer userId) {
        this.userId = userId;
    }

    public String getUserName() {
        return this.userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserEmail() {
        return userEmail;
    }

    public void setUserEmail(String userEmail) {
        this.userEmail = userEmail;
    }

    public String getUserAvatar() {
        return userAvatar;
    }

    public void setUserAvatar(String userAvatar) {
        this.userAvatar = userAvatar;
    }

    public Integer getProjectId() {
        return this.projectId;
    }

    public void setProjectId(Integer projectId) {
        this.projectId = projectId;
    }

    public EventProject getProject() {
        return project;
    }

    public void setProject(EventProject project) {
        this.project = project;
    }

    public List<RepositoryChange> getChanges() {
        return changes;
    }

    public void setChanges(List<RepositoryChange> changes) {
        this.changes = changes;
    }

    public List<String> getRefs() {
        return refs;
    }

    public void setRefs(List<String> refs) {
        this.refs = refs;
    }
}

==> gitlab4j-api-4.9.11-sources.jar: org/gitlab4j/api/systemhooks/RepositorySystemHookEvent.java <==
package org.gitlab4j.api.systemhooks;

import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.gitlab4j.api.webhook.EventProject;

@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class RepositorySystemHookEvent extends AbstractSystemHookEvent {

    public static final String REPOSITORY_UPDATE_EVENT = "repository_update";

    private String eventName;
    private Integer userId;
    private String userName;
    private String userEmail;
    private String userAvatar;

    private Integer projectId;
    private EventProject project;

    private List<RepositoryChange> changes;
    private List<String> refs;

    public String getEventName() {
        return (eventName);
    }

    public void setEventName(String eventName) {
        this.eventName = eventName;
    }

    public Integer getUserId() {
        return this.userId;
    }

    public void setUserId(Integer userId) {
        this.userId = userId;
    }

    public String getUserName() {
        return this.userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserEmail() {
        return userEmail;
    }

    public void setUserEmail(String userEmail) {
        this.userEmail = userEmail;
    }

    public String getUserAvatar() {
        return userAvatar;
    }

    public void setUserAvatar(String userAvatar) {
        this.userAvatar = userAvatar;
    }

    public Integer getProjectId() {
        return this.projectId;
    }

    public void setProjectId(Integer projectId) {
        this.projectId = projectId;
    }

    public EventProject getProject() {
        return project;
    }

    public void setProject(EventProject project) {
        this.project = project;
    }

    public List<RepositoryChange> getChanges() {
        return changes;
    }

    public void setChanges(List<RepositoryChange> changes) {
        this.changes = changes;
    }

    public List<String> getRefs() {
        return refs;
    }

    public void setRefs(List<String> refs) {
        this.refs = refs;
    }
}
